@@ -46,11 +46,10 @@ import org.apache.fop.pdf.PDFResources;
 import org.apache.fop.pdf.PDFStructElem;
 
 import org.apache.fop.render.pdf.pdfbox.PDFBoxAdapter;
+import org.apache.fop.render.pdf.pdfbox.PDFBoxAdapterTestCase;
 import org.apache.fop.render.pdf.pdfbox.PageParentTreeFinder;
 import org.apache.fop.render.pdf.pdfbox.StructureTreeMerger;
 
-
-
 public class StructureTreeMergerTestCase {
     private static final String LINK = "linkTagged.pdf";
     private static final String BrokenLink = "brokenLink.pdf";
@@ -76,6 +75,7 @@ public class StructureTreeMergerTestCase {
         checkMarkedContentsParentsForLinkTest(array);
         PDFStructElem first = (PDFStructElem)array.get(0);
         checkParentForLinkTest(first, 0);
+        doc.close();
     }
 
     @Test
@@ -93,6 +93,7 @@ public class StructureTreeMergerTestCase {
         merger.copyStructure(markedContentParents);
         PDFArray array = handler.getPageParentTree();
         Assert.assertNull(array.get(0));
+        doc.close();
     }
 
     @Test
@@ -107,6 +108,7 @@ public class StructureTreeMergerTestCase {
         PDFLogicalStructureHandler handler = setUpPDFLogicalStructureHandler();
         StructureTreeMerger merger = new StructureTreeMerger(elem, handler, adapter, srcPage);
         merger.copyStructure(markedContentParents);
+        doc.close();
 //        PDFArray array = handler.getPageParentTree();
 
 //        PDFStructElem kid = (PDFStructElem)array.get(0);
@@ -194,6 +196,7 @@ public class StructureTreeMergerTestCase {
         PDFStructElem parentElem = (PDFStructElem)array.get(1);
         PDFDictionary objrDict = (PDFDictionary) parentElem.getKids().get(1);
         Assert.assertNull(objrDict.get("Obj"));
+        doc.close();
     }
 
     @Test
